@@ -413,7 +413,7 @@ class HandlerWorker:
     def process(self):
         try:
             path = self.path and Pathy.fluid(self.path)
-            ds = self.ds or pydicom.dcmread(self.f or path)
+            ds = self.ds or pydicom.dcmread(self.f or path.open())
             params = self.file_params(ds, ae_title=self.ae_title, filename=getattr(path, 'stem', None))
             logger.info(f'processing {params}')
             extracted = self.args.extracted
